@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.2.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -47,7 +48,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.2"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -65,7 +66,7 @@
 
 
 /* First part of user prologue.  */
-#line 1 "getdate.y" /* yacc.c:338  */
+#line 1 "getdate.y" /* yacc.c:337  */
 
 /*
 **  Originally written by Steven M. Bellovin <smb@research.att.com> while
@@ -236,7 +237,7 @@ static int	yyRelSeconds;
 static int	yyRelYear;
 
 
-#line 240 "getdate.c" /* yacc.c:338  */
+#line 241 "getdate.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -312,12 +313,12 @@ extern int yydebug;
 
 union YYSTYPE
 {
-#line 172 "getdate.y" /* yacc.c:353  */
+#line 172 "getdate.y" /* yacc.c:352  */
 
     int			Number;
     enum _MERIDIAN	Meridian;
 
-#line 321 "getdate.c" /* yacc.c:353  */
+#line 322 "getdate.c" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -576,16 +577,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  61
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   273
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
   ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -777,22 +778,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -907,7 +908,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               );
       YYFPRINTF (stderr, "\n");
     }
@@ -1011,7 +1012,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -1107,10 +1111,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1134,9 +1138,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1262,23 +1267,31 @@ yyparse (void)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
   *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
       YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1297,10 +1310,7 @@ yyparse (void)
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1316,12 +1326,11 @@ yyparse (void)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
@@ -1332,6 +1341,7 @@ yyparse (void)
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1340,11 +1350,11 @@ yyparse (void)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1417,7 +1427,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1438,69 +1448,69 @@ yyreduce:
   switch (yyn)
     {
         case 4:
-#line 192 "getdate.y" /* yacc.c:1645  */
+#line 192 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHaveTime++;
 	}
-#line 1446 "getdate.c" /* yacc.c:1645  */
+#line 1456 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 5:
-#line 195 "getdate.y" /* yacc.c:1645  */
+#line 195 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHaveZone++;
 	}
-#line 1454 "getdate.c" /* yacc.c:1645  */
+#line 1464 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 198 "getdate.y" /* yacc.c:1645  */
+#line 198 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHaveDate++;
 	}
-#line 1462 "getdate.c" /* yacc.c:1645  */
+#line 1472 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 201 "getdate.y" /* yacc.c:1645  */
+#line 201 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHaveDay++;
 	}
-#line 1470 "getdate.c" /* yacc.c:1645  */
+#line 1480 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 204 "getdate.y" /* yacc.c:1645  */
+#line 204 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHaveRel++;
 	}
-#line 1478 "getdate.c" /* yacc.c:1645  */
+#line 1488 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 210 "getdate.y" /* yacc.c:1645  */
+#line 210 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHour = (yyvsp[-1].Number);
 	    yyMinutes = 0;
 	    yySeconds = 0;
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1489 "getdate.c" /* yacc.c:1645  */
+#line 1499 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 216 "getdate.y" /* yacc.c:1645  */
+#line 216 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
 	    yySeconds = 0;
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1500 "getdate.c" /* yacc.c:1645  */
+#line 1510 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 222 "getdate.y" /* yacc.c:1645  */
+#line 222 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHour = (yyvsp[-3].Number);
 	    yyMinutes = (yyvsp[-1].Number);
@@ -1510,22 +1520,22 @@ yyreduce:
 			  ? -(yyvsp[0].Number) % 100 + (-(yyvsp[0].Number) / 100) * 60
 			  : - ((yyvsp[0].Number) % 100 + ((yyvsp[0].Number) / 100) * 60));
 	}
-#line 1514 "getdate.c" /* yacc.c:1645  */
+#line 1524 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 231 "getdate.y" /* yacc.c:1645  */
+#line 231 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
 	    yySeconds = (yyvsp[-1].Number);
 	    yyMeridian = (yyvsp[0].Meridian);
 	}
-#line 1525 "getdate.c" /* yacc.c:1645  */
+#line 1535 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 237 "getdate.y" /* yacc.c:1645  */
+#line 237 "getdate.y" /* yacc.c:1652  */
     {
 	    yyHour = (yyvsp[-5].Number);
 	    yyMinutes = (yyvsp[-3].Number);
@@ -1536,71 +1546,71 @@ yyreduce:
 			  ? -(yyvsp[0].Number) % 100 + (-(yyvsp[0].Number) / 100) * 60
 			  : - ((yyvsp[0].Number) % 100 + ((yyvsp[0].Number) / 100) * 60));
 	}
-#line 1540 "getdate.c" /* yacc.c:1645  */
+#line 1550 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 249 "getdate.y" /* yacc.c:1645  */
+#line 249 "getdate.y" /* yacc.c:1652  */
     {
 	    yyTimezone = (yyvsp[0].Number);
 	}
-#line 1548 "getdate.c" /* yacc.c:1645  */
+#line 1558 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 252 "getdate.y" /* yacc.c:1645  */
+#line 252 "getdate.y" /* yacc.c:1652  */
     {
 	    yyTimezone = (yyvsp[0].Number) - 60;
 	}
-#line 1556 "getdate.c" /* yacc.c:1645  */
+#line 1566 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 256 "getdate.y" /* yacc.c:1645  */
+#line 256 "getdate.y" /* yacc.c:1652  */
     {
 	    yyTimezone = (yyvsp[-1].Number) - 60;
 	}
-#line 1564 "getdate.c" /* yacc.c:1645  */
+#line 1574 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 261 "getdate.y" /* yacc.c:1645  */
+#line 261 "getdate.y" /* yacc.c:1652  */
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[0].Number);
 	}
-#line 1573 "getdate.c" /* yacc.c:1645  */
+#line 1583 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 265 "getdate.y" /* yacc.c:1645  */
+#line 265 "getdate.y" /* yacc.c:1652  */
     {
 	    yyDayOrdinal = 1;
 	    yyDayNumber = (yyvsp[-1].Number);
 	}
-#line 1582 "getdate.c" /* yacc.c:1645  */
+#line 1592 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 269 "getdate.y" /* yacc.c:1645  */
+#line 269 "getdate.y" /* yacc.c:1652  */
     {
 	    yyDayOrdinal = (yyvsp[-1].Number);
 	    yyDayNumber = (yyvsp[0].Number);
 	}
-#line 1591 "getdate.c" /* yacc.c:1645  */
+#line 1601 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 275 "getdate.y" /* yacc.c:1645  */
+#line 275 "getdate.y" /* yacc.c:1652  */
     {
 	    yyMonth = (yyvsp[-2].Number);
 	    yyDay = (yyvsp[0].Number);
 	}
-#line 1600 "getdate.c" /* yacc.c:1645  */
+#line 1610 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 279 "getdate.y" /* yacc.c:1645  */
+#line 279 "getdate.y" /* yacc.c:1652  */
     {
 	  /* Interpret as YYYY/MM/DD if $1 >= 1000, otherwise as MM/DD/YY.
 	     The goal in recognizing YYYY/MM/DD is solely to support legacy
@@ -1619,71 +1629,71 @@ yyreduce:
 	      yyYear = (yyvsp[0].Number);
 	    }
 	}
-#line 1623 "getdate.c" /* yacc.c:1645  */
+#line 1633 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 297 "getdate.y" /* yacc.c:1645  */
+#line 297 "getdate.y" /* yacc.c:1652  */
     {
 	    /* ISO 8601 format.  yyyy-mm-dd.  */
 	    yyYear = (yyvsp[-2].Number);
 	    yyMonth = -(yyvsp[-1].Number);
 	    yyDay = -(yyvsp[0].Number);
 	}
-#line 1634 "getdate.c" /* yacc.c:1645  */
+#line 1644 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 24:
-#line 303 "getdate.y" /* yacc.c:1645  */
+#line 303 "getdate.y" /* yacc.c:1652  */
     {
 	    /* e.g. 17-JUN-1992.  */
 	    yyDay = (yyvsp[-2].Number);
 	    yyMonth = (yyvsp[-1].Number);
 	    yyYear = -(yyvsp[0].Number);
 	}
-#line 1645 "getdate.c" /* yacc.c:1645  */
+#line 1655 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 25:
-#line 309 "getdate.y" /* yacc.c:1645  */
+#line 309 "getdate.y" /* yacc.c:1652  */
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[0].Number);
 	}
-#line 1654 "getdate.c" /* yacc.c:1645  */
+#line 1664 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 26:
-#line 313 "getdate.y" /* yacc.c:1645  */
+#line 313 "getdate.y" /* yacc.c:1652  */
     {
 	    yyMonth = (yyvsp[-3].Number);
 	    yyDay = (yyvsp[-2].Number);
 	    yyYear = (yyvsp[0].Number);
 	}
-#line 1664 "getdate.c" /* yacc.c:1645  */
+#line 1674 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 27:
-#line 318 "getdate.y" /* yacc.c:1645  */
+#line 318 "getdate.y" /* yacc.c:1652  */
     {
 	    yyMonth = (yyvsp[0].Number);
 	    yyDay = (yyvsp[-1].Number);
 	}
-#line 1673 "getdate.c" /* yacc.c:1645  */
+#line 1683 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 28:
-#line 322 "getdate.y" /* yacc.c:1645  */
+#line 322 "getdate.y" /* yacc.c:1652  */
     {
 	    yyMonth = (yyvsp[-1].Number);
 	    yyDay = (yyvsp[-2].Number);
 	    yyYear = (yyvsp[0].Number);
 	}
-#line 1683 "getdate.c" /* yacc.c:1645  */
+#line 1693 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 29:
-#line 329 "getdate.y" /* yacc.c:1645  */
+#line 329 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelSeconds = -yyRelSeconds;
 	    yyRelMinutes = -yyRelMinutes;
@@ -1692,155 +1702,155 @@ yyreduce:
 	    yyRelMonth = -yyRelMonth;
 	    yyRelYear = -yyRelYear;
 	}
-#line 1696 "getdate.c" /* yacc.c:1645  */
+#line 1706 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 31:
-#line 340 "getdate.y" /* yacc.c:1645  */
+#line 340 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelYear += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1704 "getdate.c" /* yacc.c:1645  */
+#line 1714 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 32:
-#line 343 "getdate.y" /* yacc.c:1645  */
+#line 343 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelYear += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1712 "getdate.c" /* yacc.c:1645  */
+#line 1722 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 33:
-#line 346 "getdate.y" /* yacc.c:1645  */
+#line 346 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelYear++;
 	}
-#line 1720 "getdate.c" /* yacc.c:1645  */
+#line 1730 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 34:
-#line 349 "getdate.y" /* yacc.c:1645  */
+#line 349 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1728 "getdate.c" /* yacc.c:1645  */
+#line 1738 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 35:
-#line 352 "getdate.y" /* yacc.c:1645  */
+#line 352 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelMonth += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1736 "getdate.c" /* yacc.c:1645  */
+#line 1746 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 36:
-#line 355 "getdate.y" /* yacc.c:1645  */
+#line 355 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelMonth++;
 	}
-#line 1744 "getdate.c" /* yacc.c:1645  */
+#line 1754 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 37:
-#line 358 "getdate.y" /* yacc.c:1645  */
+#line 358 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelDay += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1752 "getdate.c" /* yacc.c:1645  */
+#line 1762 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 38:
-#line 361 "getdate.y" /* yacc.c:1645  */
+#line 361 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelDay += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1760 "getdate.c" /* yacc.c:1645  */
+#line 1770 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 39:
-#line 364 "getdate.y" /* yacc.c:1645  */
+#line 364 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelDay++;
 	}
-#line 1768 "getdate.c" /* yacc.c:1645  */
+#line 1778 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 40:
-#line 367 "getdate.y" /* yacc.c:1645  */
+#line 367 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelHour += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1776 "getdate.c" /* yacc.c:1645  */
+#line 1786 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 41:
-#line 370 "getdate.y" /* yacc.c:1645  */
+#line 370 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelHour += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1784 "getdate.c" /* yacc.c:1645  */
+#line 1794 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 42:
-#line 373 "getdate.y" /* yacc.c:1645  */
+#line 373 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelHour++;
 	}
-#line 1792 "getdate.c" /* yacc.c:1645  */
+#line 1802 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 43:
-#line 376 "getdate.y" /* yacc.c:1645  */
+#line 376 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelMinutes += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1800 "getdate.c" /* yacc.c:1645  */
+#line 1810 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 44:
-#line 379 "getdate.y" /* yacc.c:1645  */
+#line 379 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelMinutes += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1808 "getdate.c" /* yacc.c:1645  */
+#line 1818 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 45:
-#line 382 "getdate.y" /* yacc.c:1645  */
+#line 382 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelMinutes++;
 	}
-#line 1816 "getdate.c" /* yacc.c:1645  */
+#line 1826 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 46:
-#line 385 "getdate.y" /* yacc.c:1645  */
+#line 385 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1824 "getdate.c" /* yacc.c:1645  */
+#line 1834 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 47:
-#line 388 "getdate.y" /* yacc.c:1645  */
+#line 388 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelSeconds += (yyvsp[-1].Number) * (yyvsp[0].Number);
 	}
-#line 1832 "getdate.c" /* yacc.c:1645  */
+#line 1842 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 48:
-#line 391 "getdate.y" /* yacc.c:1645  */
+#line 391 "getdate.y" /* yacc.c:1652  */
     {
 	    yyRelSeconds++;
 	}
-#line 1840 "getdate.c" /* yacc.c:1645  */
+#line 1850 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 49:
-#line 397 "getdate.y" /* yacc.c:1645  */
+#line 397 "getdate.y" /* yacc.c:1652  */
     {
 	    if ((yyHaveTime != 0) && (yyHaveDate != 0) && (yyHaveRel == 0))
 	      yyYear = (yyvsp[0].Number);
@@ -1871,27 +1881,27 @@ yyreduce:
 		  }
 	      }
 	  }
-#line 1875 "getdate.c" /* yacc.c:1645  */
+#line 1885 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 50:
-#line 430 "getdate.y" /* yacc.c:1645  */
+#line 430 "getdate.y" /* yacc.c:1652  */
     {
 	    (yyval.Meridian) = MER24;
 	  }
-#line 1883 "getdate.c" /* yacc.c:1645  */
+#line 1893 "getdate.c" /* yacc.c:1652  */
     break;
 
   case 51:
-#line 434 "getdate.y" /* yacc.c:1645  */
+#line 434 "getdate.y" /* yacc.c:1652  */
     {
 	    (yyval.Meridian) = (yyvsp[0].Meridian);
 	  }
-#line 1891 "getdate.c" /* yacc.c:1645  */
+#line 1901 "getdate.c" /* yacc.c:1652  */
     break;
 
 
-#line 1895 "getdate.c" /* yacc.c:1645  */
+#line 1905 "getdate.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2005,12 +2015,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -2072,6 +2080,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -2079,6 +2088,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -2089,6 +2099,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -2118,7 +2132,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 439 "getdate.y" /* yacc.c:1903  */
+#line 439 "getdate.y" /* yacc.c:1918  */
 
 
 /* Month and day table. */
